<h1>Cardsec</h1>
<h3>Security Assessment Tool for Cardano SPOs</h3>
<br>
<p>
  <h3> Prerequisites </h3>
  <ul>
    <li> Linux System
    <li> Python 3.6 or above
  </ul>
</p>
<br>
<p>
  <h3> Installation </h3>

```python
  sudo pip3 install cardsec
```
</p>
<br>
<p>
  <h3> Usage </h3>

```shell
  cardsec
```
</p>
<br>
<p>
  <img src="/img/cardsec.gif?raw=true" width="470" height="400"/>
</p>
<br>
